@@ -1,10 +1,9 @@
 #!/bin/sh
 
-ACLOCAL="aclocal -I ${PWD}/m4"
+ACLOCAL="aclocal -I m4 -I config"
 AUTOHEADER="autoheader"
 AUTOMAKE="automake --add-missing --copy --foreign"
 AUTOCONF="autoconf"
-ACINCLUDE_FILES="lyxinclude.m4 libtool.m4 xforms.m4 qt.m4 gtk--.m4 gnome--.m4 gnome.m4 spell.m4 pkg.m4"
 
 # Discover what version of automake we are using.
 automake_version=`$AUTOMAKE --version 2>/dev/null | head -n 1`
@@ -12,21 +11,21 @@ automake_version=`$AUTOMAKE --version 2>/dev/null | head -n 1`
 test "$automake_version" != "" && {
     echo "Using $automake_version"
 } || {
-    echo "LyX requires automake >= 1.9"
+    echo "LyX requires automake >= 1.5"
     exit 1
 }
 
 case $automake_version in
-    *' '1.9*)
+    *' '1.[5-9]*|*' '1.10*)
 	;;
     *)
-    
+
 	echo "This automake version is not supported by LyX."
-        echo "LyX only supports automake 1.9."
-        exit 1
-        ;;
+	echo "LyX only supports automake 1.5 to 1.10."
+	exit 1
+	;;
 esac
-							
+
 # Discover what version of autoconf we are using.
 autoversion=`$AUTOCONF --version 2>/dev/null | head -n 1`
 
@@ -36,14 +35,13 @@ test "$autoversion" != "" && {
     echo "LyX requires autoconf >= 2.52"
     exit 1
 }
-	    
+
 case $autoversion in
-    *' '2.5[2-9])
-	EXTRA_ACINCLUDE_FILES="lyxinclude25x.m4"
+    *' '2.5[2-9]|*' '2.60[ab]|*' '2.6[0-1])
 	;;
     *)
 	echo "This autoconf version is not supported by LyX."
-	echo "LyX only supports autoconf 2.5[2-9]."
+	echo "LyX only supports autoconf 2.52-2.61."
 	exit 1
 	;;
 esac
@@ -72,12 +70,6 @@ fi
 # automake will stop if their contents was created by an earlier version.
 rm -rf autom4te.cache
 
-# Generate acinclude.m4
-echo -n "Generate acinclude.m4... "
-rm -f acinclude.m4
-(cd config ; cat ${ACINCLUDE_FILES} ${EXTRA_ACINCLUDE_FILES} >../acinclude.m4)
-echo "done."
-
 # Generate the Makefiles and configure files
 if ( $ACLOCAL --version ) < /dev/null > /dev/null 2>&1; then
 	echo "Building macros..."
