@@ -1547,6 +1547,7 @@ lib_images_files = Split('''
     banner.png
     bookmark-goto.xpm
     bookmark-save.xpm
+    box-insert.xpm
     break-line.xpm
     buffer-close.xpm
     buffer-export_dvi.xpm
@@ -1682,7 +1683,6 @@ lib_images_math_files = Split('''
     Re.xpm
     Rrightarrow.xpm
     Rsh.xpm
-    Vert.xpm
     Vvdash.xpm
     acute.xpm
     aleph.xpm
@@ -2155,6 +2155,8 @@ lib_images_math_files = Split('''
     vec.xpm
     vee.xpm
     veebar.xpm
+    vert.xpm
+    vert2.xpm
     vphantom.xpm
     wedge.xpm
     widehat.xpm
@@ -2213,7 +2215,9 @@ lib_doc_files = Split('''
     EmbeddedObjects.lyx
     Extended.lyx
     FAQ.lyx
+    Formula-numbering.lyx
     Intro.lyx
+    Math.lyx
     LaTeXConfig.lyx.in
     Reference.lyx
     Tutorial.lyx
@@ -2284,7 +2288,9 @@ lib_doc_de_files = Split('''
     EmbeddedObjects.lyx
     Extended.lyx
     FAQ.lyx
+    Formelnummerierung.lyx
     Intro.lyx
+    Math.lyx
     Tutorial.lyx
     UserGuide.lyx
 ''')
@@ -2318,18 +2324,15 @@ lib_doc_es_files = Split('''
     DocumentoTextoPostizo.txt
     EmbeddedObjects.lyx
     Extended.lyx
+    FAQ.lyx
+    Formula-numbering.lyx
     Intro.lyx
+    Math.lyx
     Tutorial.lyx
     UserGuide.lyx
 ''')
 
 
-lib_doc_es_biblio_files = Split('''
-    alphadin.bst
-    LyXDocs.bib
-''')
-
-
 lib_doc_es_clipart_files = Split('''
     ComentNotaImagenQt4.png
     CuadroMinipagQt4.png
@@ -2360,10 +2363,15 @@ lib_doc_eu_files = Split('''
 
 lib_doc_fr_files = Split('''
     Customization.lyx
+    DocumentBidon1.lyx
+    DocumentBidon2.lyx
+    DocumentTexteBidon.txt
     EmbeddedObjects.lyx
     Extended.lyx
     FAQ.lyx
+    Formula-numbering.lyx
     Intro.lyx
+    Math.lyx
     Tutorial.lyx
     UserGuide.lyx
 ''')
@@ -2409,6 +2417,12 @@ lib_doc_it_files = Split('''
 ''')
 
 
+lib_doc_it_clipart_files = Split('''
+    it_footnoteQt4.png
+    it_referenceQt4.png
+''')
+
+
 lib_doc_nb_files = Split('''
     Intro.lyx
 ''')
@@ -2472,6 +2486,7 @@ lib_examples_files = Split('''
     Minipage.lyx
     aa_sample.lyx
     aas_sample.lyx
+    addressExample.adr
     amsart-test.lyx
     amsbook-test.lyx
     armenian-article.lyx
@@ -2500,12 +2515,14 @@ lib_examples_files = Split('''
     landslide.lyx
     listerrors.lyx
     listings.lyx
-    mathed.lyx
     modernCV.lyx
     multicol.lyx
     noweb2lyx.lyx
     powerdot-example.lyx
     script_form.lyx
+    serial_letter1.lyx
+    serial_letter2.lyx
+    serial_letter3.lyx
     simplecv.lyx
     splash.lyx
 ''')
@@ -2533,8 +2550,10 @@ lib_examples_de_files = Split('''
     Minipage.lyx
     beispiel_gelyxt.lyx
     beispiel_roh.lyx
-    mathed.lyx
     multicol.lyx
+    serienbrief1.lyx
+    serienbrief2.lyx
+    serienbrief3.lyx
     splash.lyx
 ''')
 
@@ -2551,7 +2570,6 @@ lib_examples_fr_files = Split('''
     Minipage.lyx
     exemple_brut.lyx
     exemple_lyxifie.lyx
-    mathed.lyx
     multicol.lyx
     simplecv.lyx
     splash.lyx
@@ -2562,6 +2580,7 @@ lib_examples_es_files = Split('''
     ItemizeBullets.lyx
     ejemplo_con_lyx.lyx
     ejemplo_sin_lyx.lyx
+    mathed.lyx
     splash.lyx
 ''')
 
@@ -2600,6 +2619,11 @@ lib_examples_it_files = Split('''
 ''')
 
 
+lib_examples_ja_files = Split('''
+    splash.lyx
+''')
+
+
 lib_examples_nl_files = Split('''
     multicol.lyx
     opsommingstekens.lyx
@@ -2682,6 +2706,7 @@ lib_layouts_files = Split('''
     arab-article.layout
     armenian-article.layout
     article.layout
+    article-beamer.layout
     beamer.layout
     book.layout
     broadway.layout
@@ -2733,6 +2758,7 @@ lib_layouts_files = Split('''
     revtex.layout
     revtex4.layout
     scrartcl.layout
+    scrarticle-beamer.layout
     scrbook.layout
     scrlettr.layout
     scrlttr2.layout
@@ -2794,6 +2820,7 @@ lib_scripts_files = Split('''
     TeXFiles.py
     clean_dvi.py
     convertDefault.py
+    csv2lyx.py
     date.py
     ext_copy.py
     fen2ascii.py
