@@ -520,7 +520,11 @@ string const BufferParams::readToken(Lexer & lex, string const & token)
 		paragraph_separation = parseptranslator().find(parsep);
 	} else if (token == "\\defskip") {
 		lex.next();
-		pimpl_->defskip = VSpace(lex.getString());
+		string defskip = lex.getString();
+		if (defskip == "defskip")
+			// this is invalid
+			defskip = "medskip";
+		pimpl_->defskip = VSpace(defskip);
 	} else if (token == "\\quotes_language") {
 		string quotes_lang;
 		lex >> quotes_lang;
@@ -1089,13 +1093,17 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 	// The optional packages;
 	docstring lyxpreamble(from_ascii(features.getPackages()));
 
-	// this might be useful...
-	lyxpreamble += "\n\\makeatletter\n";
+	// only add \makeatletter and \makeatother when actually needed
+	bool makeatletter = false;
 
 	// Some macros LyX will need
 	docstring tmppreamble(from_ascii(features.getMacros()));
 
 	if (!tmppreamble.empty()) {
+		if (!makeatletter) {
+			lyxpreamble += "\n\\makeatletter\n";
+			makeatletter = true;
+		}
 		lyxpreamble += "\n%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% "
 			"LyX specific LaTeX commands.\n"
 			+ tmppreamble + '\n';
@@ -1104,6 +1112,10 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 	// the text class specific preamble
 	tmppreamble = features.getTClassPreamble();
 	if (!tmppreamble.empty()) {
+		if (!makeatletter) {
+			lyxpreamble += "\n\\makeatletter\n";
+			makeatletter = true;
+		}
 		lyxpreamble += "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% "
 			"Textclass specific LaTeX commands.\n"
 			+ tmppreamble + '\n';
@@ -1111,6 +1123,10 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 
 	/* the user-defined preamble */
 	if (!preamble.empty()) {
+		if (!makeatletter) {
+			lyxpreamble += "\n\\makeatletter\n";
+			makeatletter = true;
+		}
 		// FIXME UNICODE
 		lyxpreamble += "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% "
 			"User specified LaTeX commands.\n"
@@ -1149,8 +1165,16 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 		}
 	}
 
-	if (!bullets_def.empty())
+	if (!bullets_def.empty()) {
+		if (!makeatletter) {
+			lyxpreamble += "\n\\makeatletter\n";
+			makeatletter = true;
+		}
 		lyxpreamble += bullets_def + "}\n\n";
+	}
+
+	if (makeatletter)
+		lyxpreamble += "\\makeatother\n\n";
 
 	// We try to load babel late, in case it interferes
 	// with other packages.
@@ -1158,11 +1182,9 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 	if (use_babel && !features.isRequired("jurabib")) {
 		// FIXME UNICODE
 		lyxpreamble += from_utf8(babelCall(language_options.str())) + '\n';
-		lyxpreamble += from_utf8(features.getBabelOptions());
+		lyxpreamble += from_utf8(features.getBabelOptions()) + '\n';
 	}
 
-	lyxpreamble += "\\makeatother\n\n";
-
 	int const nlines =
 		int(lyx::count(lyxpreamble.begin(), lyxpreamble.end(), '\n'));
 	for (int j = 0; j != nlines; ++j) {
@@ -1306,27 +1328,62 @@ void BufferParams::readBulletsLaTeX(Lexer & lex)
 }
 
 
-string const BufferParams::paperSizeName() const
+string const BufferParams::paperSizeName(Papersize_Purpose const & purpose) const
 {
 	char real_papersize = papersize;
 	if (real_papersize == PAPER_DEFAULT)
 		real_papersize = lyxrc.default_papersize;
 
 	switch (real_papersize) {
+	case PAPER_DEFAULT:
+		// could be anything, so don't guess
+		return string();
+	case PAPER_CUSTOM: {
+		if (purpose == XDVI && !paperwidth.empty() &&
+		    !paperheight.empty()) {
+			// heightxwidth<unit>
+			string first = paperwidth;
+			string second = paperheight;
+			if (orientation == ORIENTATION_LANDSCAPE)
+				first.swap(second);
+			// cut off unit.
+			return first.erase(first.length() - 2)
+				+ "x" + second;
+		}
+		return string();
+	}
 	case PAPER_A3:
 		return "a3";
 	case PAPER_A4:
 		return "a4";
 	case PAPER_A5:
 		return "a5";
+	case PAPER_B3:
+		// dvips and dvipdfm do not know this
+		if (purpose == DVIPS || purpose == DVIPDFM)
+			return string();
+		return "b3";
+	case PAPER_B4:
+		// dvipdfm does not know this
+		if (purpose == DVIPDFM)
+			return string();
+		return "b4";
 	case PAPER_B5:
+		// dvipdfm does not know this
+		if (purpose == DVIPDFM)
+			return string();
 		return "b5";
 	case PAPER_USEXECUTIVE:
+		// dvipdfm does not know this
+		if (purpose == DVIPDFM)
+			return string();
 		return "foolscap";
 	case PAPER_USLEGAL:
 		return "legal";
 	case PAPER_USLETTER:
 	default:
+		if (purpose == XDVI)
+			return "us";
 		return "letter";
 	}
 }
@@ -1346,9 +1403,9 @@ string const BufferParams::dvips_options() const
 		result += ' ' + paperwidth;
 		result += ',' + paperheight;
 	} else {
-		string const paper_option = paperSizeName();
-		if (paper_option != "letter" ||
-		    orientation != ORIENTATION_LANDSCAPE) {
+		string const paper_option = paperSizeName(DVIPS);
+		if (!paper_option.empty() && (paper_option != "letter" ||
+		    orientation != ORIENTATION_LANDSCAPE)) {
 			// dvips won't accept -t letter -t landscape.
 			// In all other cases, include the paper size
 			// explicitly.
