@@ -16,7 +16,10 @@
 
 #include <vector>
 
-class InsetBase;
+
+namespace lyx {
+
+class Inset;
 class Buffer;
 
 
@@ -27,11 +30,11 @@ public:
 	class InsetTable {
 	public:
 		///
-		InsetTable(lyx::pos_type p, InsetBase * i) : pos(p), inset(i) {}
+		InsetTable(pos_type p, Inset * i) : pos(p), inset(i) {}
 		///
-		lyx::pos_type pos;
+		pos_type pos;
 		///
-		InsetBase * inset;
+		Inset * inset;
 	};
 	///
 	typedef std::vector<InsetTable> List;
@@ -53,25 +56,28 @@ public:
 	///
 	bool empty() const { return list_.empty(); }
 	///
-	iterator insetIterator(lyx::pos_type pos);
+	iterator insetIterator(pos_type pos);
 	///
-	const_iterator insetIterator(lyx::pos_type pos) const;
+	const_iterator insetIterator(pos_type pos) const;
 	///
-	void insert(InsetBase * inset, lyx::pos_type pos);
+	void insert(Inset * inset, pos_type pos);
 	///
-	void erase(lyx::pos_type pos);
+	void erase(pos_type pos);
 	///
-	InsetBase * release(lyx::pos_type);
+	Inset * release(pos_type);
 	///
-	InsetBase * get(lyx::pos_type pos) const;
+	Inset * get(pos_type pos) const;
 	///
-	void increasePosAfterPos(lyx::pos_type pos);
+	void increasePosAfterPos(pos_type pos);
 	///
-	void decreasePosAfterPos(lyx::pos_type pos);
+	void decreasePosAfterPos(pos_type pos);
 
 private:
 	///
 	List list_;
 };
 
+
+} // namespace lyx
+
 #endif
