@@ -128,8 +128,11 @@ void LyXAction::init()
 		{ LFUN_BUFFER_TOGGLE_READ_ONLY, "buffer-toggle-read-only", ReadOnly },
 		{ LFUN_BUFFER_UPDATE, "buffer-update", ReadOnly },
 		{ LFUN_BUFFER_VIEW, "buffer-view", ReadOnly },
+		{ LFUN_MASTER_BUFFER_UPDATE, "master-buffer-update", ReadOnly },
+		{ LFUN_MASTER_BUFFER_VIEW, "master-buffer-view", ReadOnly },
 		{ LFUN_BUFFER_WRITE, "buffer-write", ReadOnly },
 		{ LFUN_BUFFER_WRITE_AS, "buffer-write-as", ReadOnly },
+		{ LFUN_BUFFER_WRITE_ALL, "buffer-write-all", ReadOnly },
 		{ LFUN_CANCEL, "cancel", NoBuffer },
 		{ LFUN_CAPTION_INSERT, "caption-insert", Noop },
 		{ LFUN_CHAR_BACKWARD, "char-backward", ReadOnly | NoUpdate},
@@ -335,6 +338,7 @@ void LyXAction::init()
 		{ LFUN_INSET_MODIFY, "", Noop },
 		{ LFUN_INSET_DIALOG_UPDATE, "", Noop },
 		{ LFUN_INSET_SETTINGS, "inset-settings", ReadOnly },
+		{ LFUN_PARAGRAPH_PARAMS, "paragraph-params", Noop },
 		{ LFUN_PARAGRAPH_PARAMS_APPLY, "paragraph-params-apply", Noop },
 		{ LFUN_PARAGRAPH_UPDATE, "", Noop },
 		{ LFUN_EXTERNAL_EDIT, "external-edit", Noop },
