@@ -116,6 +116,7 @@ using support::addPath;
 using support::bformat;
 using support::changeExtension;
 using support::contains;
+using support::doesFileExist;
 using support::FileFilterList;
 using support::FileName;
 using support::fileSearch;
@@ -496,7 +497,7 @@ FuncStatus LyXFunc::getStatus(FuncRequest const & cmd) const
 		enable = buf->lyxvc().inUse();
 		break;
 	case LFUN_BUFFER_RELOAD:
-		enable = !buf->isUnnamed() && fs::exists(buf->fileName())
+		enable = !buf->isUnnamed() && doesFileExist(FileName(buf->fileName()))
 			&& (!buf->isClean() || buf->isExternallyModified(Buffer::timestamp_method));
 		break;
 
@@ -786,7 +787,7 @@ void showPrintError(string const & name)
 }
 
 
-void loadTextclass(string const & name)
+void loadTextclass(string const & name, string const & buf_path)
 {
 	std::pair<bool, textclass_type> const tc_pair =
 		textclasslist.numberOfClass(name);
@@ -800,7 +801,7 @@ void loadTextclass(string const & name)
 
 	textclass_type const tc = tc_pair.second;
 
-	if (!textclasslist[tc].load()) {
+	if (!textclasslist[tc].load(buf_path)) {
 		docstring s = bformat(_("The document could not be converted\n"
 						  "into the document class %1$s."),
 				   from_utf8(textclasslist[tc].name()));
@@ -1138,7 +1139,7 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 				FileName const filename(makeAbsPath(target_name,
 							lyx_view_->buffer()->filePath()));
 				FileName const dvifile(makeAbsPath(dviname, path));
-				if (fs::exists(filename.toFilesystemEncoding())) {
+				if (doesFileExist(filename)) {
 					docstring text = bformat(
 						_("The file %1$s already exists.\n\n"
 						  "Do you want to overwrite that file?"),
@@ -1761,7 +1762,7 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 			textclass_type const old_class =
 				buffer->params().textclass;
 
-			loadTextclass(argument);
+			loadTextclass(argument, buffer->filePath());
 
 			std::pair<bool, textclass_type> const tc_pair =
 				textclasslist.numberOfClass(argument);
@@ -1792,7 +1793,7 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 		}
 
 		case LFUN_TEXTCLASS_LOAD:
-			loadTextclass(argument);
+			loadTextclass(argument, lyx_view_->buffer()->filePath());
 			break;
 
 		case LFUN_LYXRC_APPLY: {
@@ -1869,6 +1870,7 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 
 		default: {
 			BOOST_ASSERT(lyx_view_);
+			view()->cursor().getPos(cursorPosBeforeDispatchX_, cursorPosBeforeDispatchY_);
 			view()->cursor().dispatch(cmd);
 			updateFlags = view()->cursor().result().update();
 			if (!view()->cursor().result().dispatched())
@@ -2054,17 +2056,23 @@ void LyXFunc::open(string const & fname)
 		filename = fname;
 
 	// get absolute path of file and add ".lyx" to the filename if
-	// necessary
-	FileName const fullname = fileSearch(string(), filename, "lyx");
+	// necessary. we allow_unreadable because the file may not exist.
+	// note that this is really misnamed: it should really be 
+	// support::may_not_exist (see filetools.h). this is fixed in
+	// trunk.
+	FileName const fullname = 
+			fileSearch(string(), filename, "lyx", support::allow_unreadable);
 	if (!fullname.empty())
 		filename = fullname.absFilename();
 
 	// if the file doesn't exist, let the user create one
-	if (!fs::exists(fullname.toFilesystemEncoding())) {
+	if (!doesFileExist(fullname)) {
 		// the user specifically chose this name. Believe him.
 		Buffer * const b = newFile(filename, string(), true);
-		if (b)
+		if (b) {
+			updateLabels(*b);
 			lyx_view_->setBuffer(b);
+		}
 		return;
 	}
 
@@ -2148,7 +2156,7 @@ void LyXFunc::doImport(string const & argument)
 
 	// if the file exists already, and we didn't do
 	// -i lyx thefile.lyx, warn
-	if (fs::exists(lyxfile.toFilesystemEncoding()) && fullname != lyxfile) {
+	if (doesFileExist(lyxfile) && fullname != lyxfile) {
 		docstring const file = makeDisplayPath(lyxfile.absFilename(), 30);
 
 		docstring text = bformat(_("The document %1$s already exists.\n\n"
@@ -2274,9 +2282,9 @@ void actOnUpdatedPrefs(LyXRC const & lyxrc_orig, LyXRC const & lyxrc_new)
 	case LyXRC::RC_DISPLAY_GRAPHICS:
 	case LyXRC::RC_DOCUMENTPATH:
 		if (lyxrc_orig.document_path != lyxrc_new.document_path) {
-			string const encoded = FileName(
-				lyxrc_new.document_path).toFilesystemEncoding();
-			if (fs::exists(encoded) && fs::is_directory(encoded))
+			FileName encoded = FileName(lyxrc_new.document_path);
+			if (doesFileExist(encoded) &&
+			    fs::is_directory(encoded.toFilesystemEncoding()))
 				support::package().document_dir() = FileName(lyxrc.document_path);
 		}
 	case LyXRC::RC_ESC_CHARS:
