@@ -27,6 +27,7 @@
 namespace lyx {
 namespace fs = boost::filesystem;
 
+using support::doesFileExist;
 using support::FileName;
 using support::addName;
 using support::libFileSearch;
@@ -154,6 +155,8 @@ bool TextClassList::read()
 						// fname, clname, desc, and avail
 						TextClass tmpl(fname, clname, desc, avail);
 						if (lyxerr.debugging(Debug::TCLASS)) {
+							// only system layout files are loaded here so no
+							// buffer path is needed.
 							tmpl.load();
 						}
 						classlist_.push_back(tmpl);
@@ -183,7 +186,7 @@ TextClassList::addTextClass(std::string const & textclass, std::string const & p
 	// only check for textclass.layout file, .cls can be anywhere in $TEXINPUTS
 	// NOTE: latex class name is defined in textclass.layout, which can be different from textclass
 	FileName const layout_file(addName(path, textclass + ".layout"));
-	if (fs::exists(layout_file.toFilesystemEncoding())) {
+	if (doesFileExist(layout_file)) {
 		LYXERR(Debug::TCLASS) << "Adding class " << textclass << " from directory " << path << endl;
 		// Read .layout file and get description, real latex classname etc
 		//
@@ -213,6 +216,10 @@ TextClassList::addTextClass(std::string const & textclass, std::string const & p
 				if (pp.first && classlist_[pp.second].description() == tmpl.description())
 					return pp;
 				classlist_.push_back(tmpl);
+				// This textclass is added on request so it will definitely be
+				// used. Load it now because other load() calls may fail if they
+				// are called in a context without buffer path information.
+				classlist_.back().load(path);
 				return make_pair(true, classlist_.size() - 1);
 			}
 		}
