@@ -1,15 +1,22 @@
+// -*- C++ -*-
 /**
  * \file WordLangTuple.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <levon@movementarian.org>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef WORD_LANG_TUPLE_H
 #define WORD_LANG_TUPLE_H
 
-#include "LString.h"
+#include "support/docstring.h"
+
+
+namespace lyx {
+
 
 /**
  * A word and its given language code ("en_US").
@@ -19,25 +26,28 @@ class WordLangTuple {
 public:
 	WordLangTuple() {}
 
-	WordLangTuple(string const & w, string const & c)
+	WordLangTuple(docstring const & w, std::string const & c)
 		: word_(w), code_(c)
 	{}
 
 	/// return the word
-	string const & word() const {
+	docstring const & word() const {
 		return word_;
 	}
 
 	/// return its language code
-	string const & lang_code() const {
+	std::string const & lang_code() const {
 		return code_;
 	}
 
 private:
 	/// the word
-	string word_;
+	docstring word_;
 	/// language code of word
-	string code_;
+	std::string code_;
 };
 
+
+} // namespace lyx
+
 #endif // WORD_LANG_TUPLE_H
