@@ -49,6 +49,8 @@
 #include <boost/bind.hpp>
 #include <boost/filesystem/operations.hpp>
 
+#include "support/textutils.h"
+#include "support/filetools.h"
 using std::min;
 using std::string;
 
@@ -59,6 +61,7 @@ using namespace std;
 
 using support::bformat;
 using support::FileName;
+using support::doesFileExist;
 using support::libFileSearch;
 using support::makeAbsPath;
 using support::makeDisplayPath;
@@ -76,7 +79,7 @@ bool readFile(Buffer * const b, FileName const & s)
 	BOOST_ASSERT(b);
 
 	// File information about normal file
-	if (!fs::exists(s.toFilesystemEncoding())) {
+	if (!doesFileExist(s)) {
 		docstring const file = makeDisplayPath(s.absFilename(), 50);
 		docstring text = bformat(_("The specified document\n%1$s"
 						     "\ncould not be read."), file);
@@ -87,8 +90,7 @@ bool readFile(Buffer * const b, FileName const & s)
 	// Check if emergency save file exists and is newer.
 	FileName const e(s.absFilename() + ".emergency");
 
-	if (fs::exists(e.toFilesystemEncoding()) &&
-	    fs::exists(s.toFilesystemEncoding()) &&
+	if (doesFileExist(e) && doesFileExist(s) &&
 	    fs::last_write_time(e.toFilesystemEncoding()) > fs::last_write_time(s.toFilesystemEncoding()))
 	{
 		docstring const file = makeDisplayPath(s.absFilename(), 20);
@@ -114,8 +116,7 @@ bool readFile(Buffer * const b, FileName const & s)
 	// Now check if autosave file is newer.
 	FileName const a(onlyPath(s.absFilename()) + '#' + onlyFilename(s.absFilename()) + '#');
 
-	if (fs::exists(a.toFilesystemEncoding()) &&
-	    fs::exists(s.toFilesystemEncoding()) &&
+	if (doesFileExist(a) && doesFileExist(s) &&
 	    fs::last_write_time(a.toFilesystemEncoding()) > fs::last_write_time(s.toFilesystemEncoding()))
 	{
 		docstring const file = makeDisplayPath(s.absFilename(), 20);
@@ -319,6 +320,33 @@ int countWords(DocIterator const & from, DocIterator const & to)
 }
 
 
+int countChars(DocIterator const & from, DocIterator const & to, bool with_blanks)
+{
+	int chars = 0;
+	int blanks = 0;
+	for (DocIterator dit = from ; dit != to ; dit.forwardPos()) {
+		if (dit.inTexted()
+		    && dit.pos() != dit.lastpos()
+		    && !dit.paragraph().isDeleted(dit.pos())) {
+			if (dit.paragraph().isInset(dit.pos())) {
+				if (dit.paragraph().getInset(dit.pos())->isLetter())
+					++chars;
+				else if (dit.paragraph().getInset(dit.pos())->isSpace() && with_blanks)
+					++blanks;
+			} else {
+				char_type const c = dit.paragraph().getChar(dit.pos());
+				if (isPrintableNonspace(c))
+					++chars;
+				else if (isSpace(c) && with_blanks)
+					++blanks;
+			}
+		}
+	}
+
+	return chars + blanks;
+}
+
+
 namespace {
 
 depth_type getDepth(DocIterator const & it)
