@@ -12,17 +12,22 @@
 #ifndef FACTORY_H
 #define FACTORY_H
 
+namespace lyx {
+
 class Buffer;
 class BufferView;
 class FuncRequest;
-class InsetBase;
-class LyXLex;
+class Inset;
+class Lexer;
 
 
 /// creates inset according to 'cmd'
-InsetBase * createInset(BufferView * bv, FuncRequest const & cmd);
+Inset * createInset(BufferView * bv, FuncRequest const & cmd);
 
 /// read inset from a file
-InsetBase * readInset(LyXLex & lex, Buffer const & buf);
+Inset * readInset(Lexer & lex, Buffer const & buf);
+
+
+} // namespace lyx
 
 #endif // FACTORY_H
