@@ -18,14 +18,12 @@
 
 #include <map>
 
-class InsetBase;
+namespace lyx {
+
+class Inset;
 class LyXView;
 
-namespace lyx {
-namespace frontend {
-class Dialog;
-} // namespace frontend
-} // namespace lyx
+namespace frontend { class Dialog; }
 
 /** Container of all dialogs.
  */
@@ -34,14 +32,6 @@ public:
 	///
 	Dialogs(LyXView &);
 
-	/** Redraw all visible dialogs because, for example, the GUI colours
-	 *  have been re-mapped.
-	 *
-	 *  Note that static boost signals break some compilers, so we return a
-	 *  reference to some hidden magic ;-)
-	 */
-	static boost::signal<void()> & redrawGUI();
-
 	/** Check the status of all visible dialogs and disable or reenable
 	 *  them as appropriate.
 	 *
@@ -51,9 +41,6 @@ public:
 	 */
 	void checkStatus();
 
-	/// Toggle tooltips on/off in all dialogs.
-	static void toggleTooltips();
-
 	/// Are the tooltips on or off?
 	static bool tooltipsEnabled();
 
@@ -86,7 +73,7 @@ public:
 	    dialog on 'Apply'; should it be used to create a new inset at
 	    the current cursor position or modify an existing, 'open' inset?
 	*/
-	void show(std::string const & name, std::string const & data, InsetBase * inset);
+	void show(std::string const & name, std::string const & data, Inset * inset);
 
 	/** \param name == "citation", "bibtex" etc; an identifier used
 	    to update the contents of a particular dialog with \param data.
@@ -100,35 +87,38 @@ public:
 	/** All Dialogs of the given \param name will be closed if they are
 	    connected to the given \param inset.
 	*/
-	static void hide(std::string const & name, InsetBase * inset);
+	void hide(std::string const & name, Inset * inset);
 	///
 	void disconnect(std::string const & name);
 	///
-	InsetBase * getOpenInset(std::string const & name) const;
+	Inset * getOpenInset(std::string const & name) const;
 private:
-	///
-	void hideSlot(std::string const & name, InsetBase * inset);
 	///
 	void redraw() const;
 	///
 	bool isValidName(std::string const & name) const;
 	///
-	lyx::frontend::Dialog * find_or_build(std::string const & name);
+	frontend::Dialog * find_or_build(std::string const & name);
 	///
-	typedef boost::shared_ptr<lyx::frontend::Dialog> DialogPtr;
+	typedef boost::shared_ptr<frontend::Dialog> DialogPtr;
 	///
 	DialogPtr build(std::string const & name);
 
 	///
 	LyXView & lyxview_;
 	///
-	std::map<std::string, InsetBase *> open_insets_;
+	std::map<std::string, Inset *> open_insets_;
 
 	///
 	std::map<std::string, DialogPtr> dialogs_;
 
 	/// flag against a race condition due to multiclicks in Qt frontend, see bug #1119
 	bool in_show_;
+
+	///
+	boost::signals::connection connection_;
 };
 
+} // namespace lyx
+
 #endif
