@@ -13,7 +13,10 @@
 #ifndef MENUBAR_H
 #define MENUBAR_H
 
-#include <string>
+#include "support/docstring.h"
+
+
+namespace lyx {
 
 /**
  * The LyX GUI independent menubar class
@@ -24,8 +27,11 @@ public:
 	///
 	virtual ~Menubar() {}
 	/// Opens a top-level submenu given its name
-	virtual void openByName(std::string const &) = 0;
+	virtual void openByName(docstring const &) = 0;
 	/// update the state of the menuitems
 	virtual void update() = 0;
 };
+
+} // namespace lyx
+
 #endif // MENUBAR_H
