@@ -14,14 +14,14 @@
 #define CONTROLBIBTEX_H
 
 #include "ControlCommand.h"
+
+#include "support/docstring.h"
+
 #include <vector>
 
 namespace lyx {
-namespace support {
 
-class FileFilterList;
-
-} // namespace support
+namespace support { class FileFilterList; }
 
 
 namespace frontend {
@@ -34,10 +34,10 @@ public:
 	ControlBibtex(Dialog &);
 
 	/// Browse for a .bib file
-	std::string const browseBib(std::string const & in_name) const;
+	docstring const browseBib(docstring const & in_name) const;
 
 	/// Browse for a .bst file
-	std::string const browseBst(std::string const & in_name) const;
+	docstring const browseBst(docstring const & in_name) const;
 
 	/// get the list of bst files
 	void getBibStyles(std::vector<std::string> & data) const;
