@@ -16,9 +16,10 @@
 #include "Dialog.h"
 #include <vector>
 
+namespace lyx {
+
 class InsetBoxParams;
 
-namespace lyx {
 namespace frontend {
 
 class ControlBox : public Dialog::Controller {
@@ -44,10 +45,10 @@ private:
 };
 
 ///
-void box_gui_tokens(std::vector<std::string> &, std::vector<std::string> &);
+void box_gui_tokens(std::vector<std::string> &, std::vector<docstring> &);
 ///
 void box_gui_tokens_special_length(std::vector<std::string> &,
-	std::vector<std::string> &);
+	std::vector<docstring> &);
 
 } // namespace frontend
 } // namespace lyx
