@@ -14,13 +14,15 @@
 #ifndef CONTROLCOMMANDBUFFER_H
 #define CONTROLCOMMANDBUFFER_H
 
-#include <string>
+#include "support/docstring.h"
+
 #include <vector>
 
 
+namespace lyx {
+
 class LyXView;
 
-namespace lyx {
 namespace frontend {
 
 /**
@@ -40,7 +42,10 @@ public:
 	std::string const historyDown();
 
 	/// return the font and depth in the active BufferView as a message.
-	std::string const getCurrentState() const;
+	docstring const getCurrentState() const;
+
+	/// hide the command buffer.
+	void hide() const;
 
 	/// return the possible completions
 	std::vector<std::string> const completions(std::string const & prefix,
