@@ -6,25 +6,38 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLSENDTO_H
 #define CONTROLSENDTO_H
 
-#include "ControlDialog_impl.h"
-#include "LString.h"
-
+#include "Dialog.h"
 #include <vector>
 
+
+namespace lyx {
+
 class Format;
 
+namespace frontend {
+
 /** A controller for the Custom Export dialogs.
  */
-class ControlSendto : public ControlDialogBD {
+class ControlSendto : public Dialog::Controller {
 public:
 	///
-	ControlSendto(LyXView &, Dialogs &);
+	ControlSendto(Dialog &);
+	///
+	virtual bool initialiseParams(std::string const & data);
+	///
+	virtual void clearParams() {}
+	///
+	virtual void dispatchParams();
+	///
+	virtual bool isBufferDependent() const { return true; }
+	///
+	virtual kb_action getLfun() const { return LFUN_BUFFER_EXPORT_CUSTOM; }
 
 	/// Return a vector of those formats that can be exported from "lyx".
 	std::vector<Format const *> const allFormats() const;
@@ -34,15 +47,16 @@ public:
 	void setFormat(Format const *);
 
 	/// The command to be executed
-	string const getCommand() const { return command_; };
-	void setCommand(string const &);
+	std::string const getCommand() const { return command_; };
+	void setCommand(std::string const &);
 private:
-	///
-	virtual void apply();
 	///
 	Format const * format_;
 	///
-	string command_;
+	std::string command_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLSENDTO_H
