@@ -1,6 +1,22 @@
 // -*- C++ -*-
-#ifndef _GETTEXT_H_
-#define _GETTEXT_H_
+/**
+ * \file src/gettext.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Lars Gullik Bjnnes
+ * \author Jean-Marc Lasgouttes
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
+#ifndef GETTEXT_H
+#define GETTEXT_H
+
+#include "support/docstring.h"
+
+
+namespace lyx {
 
 /*
  * Native Language Support
@@ -30,29 +46,32 @@
  *   Panic/fatal (that should not happen) messages need not be translated
  */
 
-#include "LString.h"
 
-#ifdef ENABLE_NLS
+//#ifdef ENABLE_NLS
 
 ///
-char const * _(char const *);
-///
-string const _(string const &);
+docstring const _(std::string const &);
 
-#else // ENABLE_NLS
+//#else // ENABLE_NLS
 
 ///
-#  define _(str) (str)
-///
-#  define S_(str) (str)
+//#  define _(str) (str)
 
-#endif
+//#endif
 
 #  define N_(str) (str)              // for detecting static strings
 
+/**
+ * Translate \p name if it is possible.
+ * This should be used to translate strings that come from configuration
+ * files like .ui files. These strings could already be in the native
+ * language if they come from a file in the personal directory. */
+docstring const translateIfPossible(docstring const & name);
+
 ///
 void locale_init();
-///
-void gettext_init(string const & localedir);
+
+
+} // namespace lyx
 
 #endif
