@@ -17,9 +17,12 @@
 
 #include <boost/utility.hpp>
 
-class LyXLex;
-
 namespace lyx {
+
+namespace support { class FileName; }
+
+class Lexer;
+
 namespace external {
 
 class Template {
@@ -27,7 +30,7 @@ public:
 	/// We have to have default commands for safety reasons!
 	Template();
 	///
-	void readTemplate(LyXLex &);
+	void readTemplate(Lexer &);
 	///
 	void dumpFormats(std::ostream &) const;
 
@@ -61,7 +64,7 @@ public:
 	public:
 		Format();
 		///
-		void readFormat(LyXLex &);
+		void readFormat(Lexer &);
 
 		/// The text that should be inserted into the exported file
 		std::string product;
@@ -81,7 +84,7 @@ public:
 		std::map<TransformID, TransformStore> option_transformers;
 
 		typedef std::map<std::string,
-		                 std::vector<std::string> > FileMap;
+				 std::vector<std::string> > FileMap;
 		/// Referenced files for some formats
 		FileMap referencedFiles;
 	};
@@ -116,7 +119,7 @@ public:
 	std::string const getPreambleDefByName(std::string const & name) const;
 private:
 	TemplateManager();
-	void readTemplates(std::string const & path);
+	void readTemplates(support::FileName const & path);
 	void dumpTemplates(std::ostream &) const;
 	void dumpPreambleDefs(std::ostream &) const;
 
