@@ -287,7 +287,7 @@ int InsetBox::latex(Buffer const & buf, odocstream & os,
 			width_string += " - 2\\fboxsep - 2\\fboxrule"/* "-\\shadowsize"*/;
 			break;
 		case Doublebox:
-			width_string += " - 2\\fboxsep - 7.5\\fboxrule - 1.0pt";
+			width_string += " - 2\\fboxsep - 7.5\\fboxrule - 1pt";
 			break;
 		}
 	}
@@ -388,9 +388,8 @@ int InsetBox::latex(Buffer const & buf, odocstream & os,
 		os << "}";
 		break;
 	}
-	os << "%\n";
 
-	i += 3;
+	i += 2;
 
 	return i;
 }
