@@ -87,7 +87,7 @@ InsetText::InsetText(BufferParams const & bp)
 
 
 InsetText::InsetText(InsetText const & in)
-	: Inset(in), text_(), fixed_width_(fixed_width_)
+	: Inset(in), fixed_width_(fixed_width_), text_()
 {
 	text_.autoBreakRows_ = in.text_.autoBreakRows_;
 	drawFrame_ = in.drawFrame_;
@@ -287,7 +287,7 @@ int InsetText::latex(Buffer const & buf, odocstream & os,
 		     OutputParams const & runparams) const
 {
 	TexRow texrow;
-	latexParagraphs(buf, paragraphs(), os, texrow, runparams);
+	latexParagraphs(buf, text_, os, texrow, runparams);
 	return texrow.rows();
 }
 
