@@ -47,8 +47,7 @@ public:
 	int docbook(Buffer const &, odocstream &,
 		    OutputParams const &) const;
 	/// the string that is passed to the TOC
-	virtual int textString(Buffer const &, odocstream &,
-		OutputParams const &) const;
+	void textString(Buffer const &, odocstream &) const;
 private:
 	virtual std::auto_ptr<Inset> doClone() const {
 		return std::auto_ptr<Inset>(new InsetUrl(params()));
