@@ -14,6 +14,7 @@
 #include "MathData.h"
 #include "MathSupport.h"
 #include "MathStream.h"
+#include "LaTeXFeatures.h"
 
 
 namespace lyx {
@@ -23,8 +24,8 @@ using std::max;
 using std::auto_ptr;
 
 
-InsetMathBinom::InsetMathBinom(bool choose)
-	: choose_(choose)
+InsetMathBinom::InsetMathBinom(Kind kind)
+	: kind_(kind)
 {}
 
 
@@ -62,29 +63,43 @@ bool InsetMathBinom::metrics(MetricsInfo & mi, Dimension & dim) const
 
 void InsetMathBinom::draw(PainterInfo & pi, int x, int y) const
 {
+	docstring const bra = kind_ == BRACE ? from_ascii("{") :
+			      kind_ == BRACK ? from_ascii("[") : from_ascii("(");
+	docstring const ket = kind_ == BRACE ? from_ascii("}") :
+			      kind_ == BRACK ? from_ascii("]") : from_ascii(")");
 	int m = x + dim_.width() / 2;
 	FracChanger dummy(pi.base);
 	cell(0).draw(pi, m - cell(0).width() / 2, y - cell(0).descent() - 3 - 5);
 	cell(1).draw(pi, m - cell(1).width() / 2, y + cell(1).ascent()  + 3 - 5);
-	mathed_draw_deco(pi, x, y - dim_.ascent(), dw(), dim_.height(), from_ascii("("));
+	mathed_draw_deco(pi, x, y - dim_.ascent(), dw(), dim_.height(), bra);
 	mathed_draw_deco(pi, x + dim_.width() - dw(), y - dim_.ascent(),
-		dw(), dim_.height(), from_ascii(")"));
+		dw(), dim_.height(), ket);
 	drawMarkers2(pi, x, y);
 }
 
 
 bool InsetMathBinom::extraBraces() const
 {
-	return choose_;
+	return kind_ == CHOOSE || kind_ == BRACE || kind_ == BRACK;
 }
 
 
 void InsetMathBinom::write(WriteStream & os) const
 {
-	if (choose_)
-		os << '{' << cell(0) << " \\choose " << cell(1) << '}';
-	else
+	switch (kind_) {
+	case BINOM:
 		os << "\\binom{" << cell(0) << "}{" << cell(1) << '}';
+		break;
+	case CHOOSE:
+		os << '{' << cell(0) << " \\choose " << cell(1) << '}';
+		break;
+	case BRACE:
+		os << '{' << cell(0) << " \\brace " << cell(1) << '}';
+		break;
+	case BRACK:
+		os << '{' << cell(0) << " \\brack " << cell(1) << '}';
+		break;
+	}
 }
 
 
@@ -94,4 +109,13 @@ void InsetMathBinom::normalize(NormalStream & os) const
 }
 
 
+void InsetMathBinom::validate(LaTeXFeatures & features) const
+{
+	if (kind_ == BINOM) {
+		features.require("binom");
+		InsetMathNest::validate(features);
+	}
+}
+
+
 } // namespace lyx
