@@ -22,7 +22,15 @@ namespace lyx {
 class InsetMathBinom : public InsetMathFracBase {
 public:
 	///
-	explicit InsetMathBinom(bool choose = false);
+	enum Kind {
+		BINOM,
+		CHOOSE,
+		BRACE,
+		BRACK
+	};
+
+	///
+	explicit InsetMathBinom(Kind kind = BINOM);
 	///
 	void write(WriteStream & os) const;
 	///
@@ -36,12 +44,14 @@ public:
 	{ drawMarkers2(pi, x, y); }
 	///
 	bool extraBraces() const;
+	///
+	void validate(LaTeXFeatures & features) const;
 private:
 	virtual std::auto_ptr<Inset> doClone() const;
 	///
 	int dw() const;
 	///
-	bool choose_;
+	Kind kind_;
 };
 
 
