@@ -14,6 +14,7 @@
 #include "MathData.h"
 #include "MathStream.h"
 #include "MathStream.h"
+#include "LaTeXFeatures.h"
 #include "support/std_ostream.h"
 
 
@@ -74,4 +75,12 @@ void InsetMathBox::infoize(odocstream & os) const
 }
 
 
+void InsetMathBox::validate(LaTeXFeatures & features) const
+{
+	if (name_ == "tag" || name_ == "tag*")
+		features.require("amsmath");
+	cell(0).validate(features);
+}
+
+
 } // namespace lyx
