@@ -17,7 +17,14 @@
 #include <boost/signals/connection.hpp>
 #include <boost/signal.hpp>
 #include <boost/signals/trackable.hpp>
-#include <boost/test/detail/nullstream.hpp>
+#include <boost/version.hpp>
+
+#if BOOST_VERSION < 103300
+# include <boost/test/detail/nullstream.hpp>
+#else
+# include <boost/test/utils/nullstream.hpp>
+#endif
+
 #include <boost/tokenizer.hpp>
 #include <boost/tuple/tuple.hpp>
 #include <boost/utility.hpp>
@@ -57,5 +64,6 @@
 #include <stack>
 #include <string>
 #include <utility>
+
 #include <utime.h>
 #include <vector>
