@@ -16,26 +16,30 @@
 
 #include "support/types.h"
 
-class LyXText;
+namespace lyx {
+
+class Text;
 class BufferView;
 class PainterInfo;
 class ViewMetricsInfo;
 
+namespace frontend { class Painter; }
 
 /// paint visible paragraph of main text
-void paintText(BufferView const & bv, ViewMetricsInfo const & vi);
+void paintText(BufferView & bv, frontend::Painter & painter);
 
 /// paint the rows of a text inset
-void paintTextInset(LyXText const & text, PainterInfo & pi, int x, int y);
+void paintTextInset(Text const & text, PainterInfo & pi, int x, int y);
 
 /// some space for drawing the 'nested' markers (in pixel)
 inline int nestMargin() { return 15; }
 
 /// margin for changebar
-inline int changebarMargin() { return 10; }
+inline int changebarMargin() { return 12; }
 
 /// right margin
 inline int rightMargin() { return 10; }
 
+} // namespace lyx
 
 #endif // ROWPAINTER_H
