@@ -14,11 +14,15 @@
 #define SGML_H
 
 #include "support/types.h"
+#include "support/docstream.h"
 
 #include <iosfwd>
 #include <string>
 #include <utility>
 
+
+namespace lyx {
+
 class Buffer;
 class Paragraph;
 class OutputParams;
@@ -27,33 +31,35 @@ namespace sgml {
 
 /**
  * Escape the given character, if necessary,
- * to an SGML entity. Returns true
- * if it was a whitespace character.
+ * to an SGML entity.
  */
-std::pair<bool, std::string> escapeChar(char c);
+docstring escapeChar(char_type c);
 
 /// Escape a word instead of a single character
-std::string escapeString(std::string const & raw);
+docstring escapeString(docstring const & raw);
 
 /// replaces illegal characters from SGML/XML ID attributes
-std::string cleanID(Buffer const & buf, OutputParams const & runparams,
-		    std::string const & orig);
+docstring cleanID(Buffer const & buf, OutputParams const & runparams,
+		    docstring const & orig);
 
 /// returns a unique numeric id
-std::string const uniqueID(std::string const label);
+docstring const uniqueID(docstring const label);
 
 /// Opens tag
-void openTag(std::ostream & os, std::string const & name,
+void openTag(odocstream & os, std::string const & name,
 	    std::string const & attribute = std::string());
 
 /// Open tag
-void openTag(Buffer const & buf, std::ostream & os,
+void openTag(Buffer const & buf, odocstream & os,
 	     OutputParams const & runparams, Paragraph const & par);
 
 /// Close tag
-void closeTag(std::ostream & os, std::string const & name);
+void closeTag(odocstream & os, std::string const & name);
 
 /// Close tag
-void closeTag(std::ostream & os, Paragraph const & par);
-}
+void closeTag(odocstream & os, Paragraph const & par);
+
+} // namespace sgml
+} // namespace lyx
+
 #endif // SGML_H
