@@ -14,6 +14,9 @@
 
 #include "support/std_ostream.h"
 
+
+namespace lyx {
+
 ///
 struct NewLineAndDepth_ {
 	int depth_;
@@ -36,4 +39,7 @@ std::ostream & operator<<(std::ostream & os, NewLineAndDepth_ const & nlad_)
 	return os;
 }
 
+
+} // namespace lyx
+
 #endif
